@@ -11,10 +11,11 @@ def is_supported(name: str, package=None) -> bool:
     return module is not None
 
 
-HJSON_SUPPORTED = is_supported('hsjon')
+DHALL_SUPPORTED = is_supported('dhall')
+HJSON_SUPPORTED = is_supported('hjson')
 INI_SUPPORTED = is_supported('ini')
 JSON5_SUPPORTED = is_supported('json5')
 YAML_SUPPORTED = is_supported('.yaml', 'ruamel')
-TOML_SUPPORTED = is_supported('qtoml')
+TOML_SUPPORTED = is_supported('qtoml') or is_supported('rtoml')
 
 PYDANTIC_SUPPORTED = is_supported('pydantic')
